# sesg

> SeSG (Search String Generator) python package repository.

[![PyPI version](https://badge.fury.io/py/sesg.svg)](https://badge.fury.io/py/sesg)
[![Documentation Status](https://readthedocs.org/projects/sesg/badge/?version=latest)](https://sesg.readthedocs.io/en/latest/?badge=latest)
[![CI](https://github.com/demetrius-mp/sesg/actions/workflows/pipeline.yaml/badge.svg)](https://github.com/demetrius-mp/sesg/actions/workflows/pipeline.yaml)
[![codecov](https://codecov.io/github/demetrius-mp/sesg/branch/main/graph/badge.svg?token=Y6DXNMDGU1)](https://codecov.io/github/demetrius-mp/sesg)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v0.json)](https://github.com/charliermarsh/ruff)
[![Docstring Style](https://img.shields.io/badge/%20style-google-3666d6.svg)](https://google.github.io/styleguide/pyguide.html#s3.8-comments-and-docstrings)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

SeSG is a tool developed to help Systematic Literature Review researchers, specifically at the step of building a search string. This is a continuation of [Leo Fuchs'](https://github.com/LeoFuchs/SeSG) work.

## Installation

You can install with `pip`, `poetry`, or any other package manager:

```bash
poetry add sesg
```

## Usage

To a complete usage example, please refer to [this repo](https://github.com/demetrius-mp/sesg-cli).
